"use strict";

this.name    = "Laserific Crosshairs"; // "Wildeblood", 2014.
this.version = "1.1";

this.$maxSteps   = 16;
this.$cutOffHeat = 0.85;

/* ====================================================================================
			STARTING & STOPPING FRAME CALLBACK

	FCB starts when player.alertCondition becomes 3 or a target is acquired.
	FCB ends when !player.ship.target && player.ship.laserHeatLevel === 0 && player.alertCondition < 3
	Display is shown while player.ship.target or player.ship.laserHeatLevel > 0 or player.alertHostiles

======================================================================================= */

    this.alertConditionChanged = function (newState, oldState) {
        "use strict";
        if (newState ==3 && !this.$runningFCB) {
            this.$runningFCB = addFrameCallback(this._monitorLaser.bind(this));
        }
    }

    this.shipTargetAcquired = function (target) {
        "use strict";
        if (!this.$runningFCB) {
            this.$runningFCB = addFrameCallback(this._monitorLaser.bind(this));
        }
    }

    this.shipWillDockWithStation = this.shipWillEnterWitchspace = this.shipDied = function () {
        "use strict";
        this._endFCB();
    }

    this._endFCB = function () {
        "use strict";
        if (this.$runningFCB) {
            removeFrameCallback(this.$runningFCB);
            delete this.$runningFCB;
        }
    }

    this._monitorLaser = function (delta) {
        "use strict";
        if (player.alertHostiles ||
            player.ship.target ||
            player.ship.laserHeatLevel) {
            this._showDisplay();
        } else {
            this._hideDisplay();
            if (player.alertCondition < 3) {
                this._endFCB();
            }
        }
    }

    this._showDisplay = function () {
        "use strict";
        var level = (player.ship.laserHeatLevel / this.$cutOffHeat * this.$maxSteps);
        var step = level.toFixed();
        if (step != this.$lastStep) {
            if (step > this.$maxSteps) {
                step = this.$maxSteps; // Thank you, javascript automatic variable typing.
            }
            player.ship.crosshairs = "wildeblood_combat_crosshairs_" + step + ".plist";
            this.$lastStep = step;
        }
    }

    this._hideDisplay = function () {
        "use strict";
     // FixMe: if alertCondition === 3 but alertHostiles === false,
     // this will hammer player.ship.crosshairs = null on every frame.
     // FixMe: player.ship.crosshairs = null causes a HUD reset;
     // similar fix to that used in Auto Crosshairs required.
        player.ship.crosshairs = null; // "crosshairs.plist";
        this.$lastStep = "-1";
    }

/* ====================================================================================
			THE END
======================================================================================= */
